from setuptools import setup

setup(
    name='bigsudo',
    version='0.2.0',
    url='https://yourlabs.io/oss/bigsudo',
    setup_requires='setupmeta',
    keywords='automation cli ansible',
    python_requires='>=3',
    include_package_data=True,
)
